@import 'some.css.file.css';
@import 'some/other.css.file.CSS';
@import 'some.css' all;
@import "some.print.css" print;
.foo {
	color: blue;
}
.mixin {
	color: red;
}
.mixin {
	color: red;
}
.import {
	color: red;
	width: 6px;
	height: 9px;
}
@import "styles.css";
@import url("styles.css");
@import url("druck.css") print;
@import url("foo.css") projection,tv;
@import url("bar.css") handheld and (max-width:500px);
