/*
	Whitespace
*/
.whitespace
  { color: white; }  
  
.whitespace
{
  color: blue;
}
.whitespace
{
  color: green;
  
  
  
  
  
  
  
  
  
  
}
  .whitespace
{ color: pink; }

.whitespace{color:yellow;}  
.whitespace { color : black ; }

.white,
.space,
.mania
{ color: white; }
.newlines {
  background: the,
              great,
              wall;
  border: 2px
          				solid
          black;
}
.empty {
  
}
.no_final_semi {
	 color: white
}
.no_final_semi1 {
color:                            yellow;	
	 color: white
	 
	 
}
@media all {
	html {
		padding: src('no semi in media block')
	}
}
@font-face {
  src: url('x') format('e'),
       url('r') format('s');
}
.form-control {
  fieldset[disabled] & {
    cursor: not-allowed;
  }
}
