#strings {
	quotes: "~""~";
	content: "#*%:&^,)!.(~*})";
	empty: "";
	brackets: "{""}";
}
#comments {
	content: "/* hello */ // not-so-secret";
}
#quotes {
	quotes: "'""'";
	quotes: '"''"';
	content: '""#!&""';
	empty: '';
	semi-colon: ';';
}
#escaped {
	filter: DX.Transform.MS.BS.filter(opacity=50);
}
.escaped {
	filter: alpha(opacity=0.1);
}
#interpolation {
	url: "http://lesscss.org/dev/image.jpg";
	url2: "http://lesscss.org/image-256.jpg";
	url3: "http://lesscss.org#445566";
	url4: "http://lesscss.org/hello";
	url5: "http://lesscss.org/54.4px";
}
