.variables {
	width: 14cm;
}
.variables {
	height: 24px;
	color: #888888;
	font-family: "Trebuchet MS", Verdana, sans-serif;
	quotes: "~""~";
}
.redefinition {
	three: 3;
}
.values {
	font-family: 'Trebuchet', 'Trebuchet', 'Trebuchet';
	color: #888888 !important;
	url: url('Trebuchet');
	multi: something 'A', B, C, 'Trebuchet';
}
.variable-names {
	name: 'hello';
}
.alpha {
	filter: alpha(opacity=42);
}
.lazy-eval {
	width: 100%;
}
.scope1 {
	color: blue;
	border-color: black;
}
.scope1 .scope2 {
	color: blue;
}
.scope1 .scope2 .scope3 {
	color: red;
	border-color: black;
	background-color: white;
}
.scope1 .scope2 .scope3 .scope4 {
	color: black;
}
.negvar {
	padding: -1px;
}
.varpad {
	border-left: 1px solid transparent;
	border-right: 1px solid transparent;
	border-top: 1px solid black;
}
.testname {
	width: 12px;
}
