.well {
  filter: e(%("progid:DXImageTransform.Microsoft.gradient(startColorstr='%d')", argb(#555)));
  color: rgba(90, 23, 148, 0.5);
  color: argb(rgb(100, 100, 100));
  color: argb(rgb(140, 100, 100, 100));
  color: argb(rgba(90, 23, 148, 50));
  color: argb(rgba(90, 23, 148, 0.5));
  color: argb(#555);
}
