.div {
	color: blue;
}
.div .nest {
	color: red;
}
.div .nest.deep {
	color: yellow;
}
.div .nest.deep .deeper {
	color: angry;
}
.div .nest.deep .deeper .deepest {
	color: purple;
}
h1 a:hover,
h2 a:hover,
h3 a:hover,
h1 p:hover,
h2 p:hover,
h3 p:hover {
	color: red;
}
a.btn-small span {
	font-size: 10px;
}
a {
	color: red;
}
a:hover {
	color: blue;
}
div a {
	color: green;
}
p a span {
	color: yellow;
}
.foo .bar .qux,
.foo .baz .qux {
	display: block;
}
.qux .foo .bar,
.qux .foo .baz {
	display: inline;
}
.qux .foo .bar .biz,
.qux .foo .baz .biz {
	display: none;
}
#first > .one {
	font-size: 2em;
}
#first > .one > #second .two > #deux {
	width: 50%;
}
#first > .one > #second .two > #deux #third {
	height: 100%;
}
#first > .one > #second .two > #deux #third:focus {
	color: black;
}
#first > .one > #second .two > #deux #third:focus #fifth > #sixth .seventh #eighth {
	color: purple;
}
#first > .one > #second .two > #deux #third:focus #fifth > #sixth .seventh #eighth + .sibling_selector {
	color: angry;
}
#first > .one > #second .two > #deux #third ~ p.general_sibling_selector {
	color: unused;
}
#first > .one > #second .two > #deux #fourth,
#first > .one > #second .two > #deux #five,
#first > .one > #second .two > #deux #six {
	color: #110000;
}
#first > .one > #second .two > #deux #fourth .seven,
#first > .one > #second .two > #deux #five .seven,
#first > .one > #second .two > #deux #six .seven,
#first > .one > #second .two > #deux #fourth .eight > #nine,
#first > .one > #second .two > #deux #five .eight > #nine,
#first > .one > #second .two > #deux #six .eight > #nine {
	border: 1px solid black;
}
#first > .one > #second .two > #deux #fourth #ten,
#first > .one > #second .two > #deux #five #ten,
#first > .one > #second .two > #deux #six #ten {
	color: red;
}
h1 a .one:hover,
h2 a .one:hover,
h3 a .one:hover,
h4 a .one:hover,
h5 a .one:hover,
h1 p .one:hover,
h2 p .one:hover,
h3 p .one:hover,
h4 p .one:hover,
h5 p .one:hover,
h1 div .one:hover,
h2 div .one:hover,
h3 div .one:hover,
h4 div .one:hover,
h5 div .one:hover,
h1 span .one:hover,
h2 span .one:hover,
h3 span .one:hover,
h4 span .one:hover,
h5 span .one:hover,
h1 a .two:hover,
h2 a .two:hover,
h3 a .two:hover,
h4 a .two:hover,
h5 a .two:hover,
h1 p .two:hover,
h2 p .two:hover,
h3 p .two:hover,
h4 p .two:hover,
h5 p .two:hover,
h1 div .two:hover,
h2 div .two:hover,
h3 div .two:hover,
h4 div .two:hover,
h5 div .two:hover,
h1 span .two:hover,
h2 span .two:hover,
h3 span .two:hover,
h4 span .two:hover,
h5 span .two:hover,
h1 a .three:hover,
h2 a .three:hover,
h3 a .three:hover,
h4 a .three:hover,
h5 a .three:hover,
h1 p .three:hover,
h2 p .three:hover,
h3 p .three:hover,
h4 p .three:hover,
h5 p .three:hover,
h1 div .three:hover,
h2 div .three:hover,
h3 div .three:hover,
h4 div .three:hover,
h5 div .three:hover,
h1 span .three:hover,
h2 span .three:hover,
h3 span .three:hover,
h4 span .three:hover,
h5 span .three:hover,
h1 a .four:hover,
h2 a .four:hover,
h3 a .four:hover,
h4 a .four:hover,
h5 a .four:hover,
h1 p .four:hover,
h2 p .four:hover,
h3 p .four:hover,
h4 p .four:hover,
h5 p .four:hover,
h1 div .four:hover,
h2 div .four:hover,
h3 div .four:hover,
h4 div .four:hover,
h5 div .four:hover,
h1 span .four:hover,
h2 span .four:hover,
h3 span .four:hover,
h4 span .four:hover,
h5 span .four:hover,
h1 a .one:focus,
h2 a .one:focus,
h3 a .one:focus,
h4 a .one:focus,
h5 a .one:focus,
h1 p .one:focus,
h2 p .one:focus,
h3 p .one:focus,
h4 p .one:focus,
h5 p .one:focus,
h1 div .one:focus,
h2 div .one:focus,
h3 div .one:focus,
h4 div .one:focus,
h5 div .one:focus,
h1 span .one:focus,
h2 span .one:focus,
h3 span .one:focus,
h4 span .one:focus,
h5 span .one:focus,
h1 a .two:focus,
h2 a .two:focus,
h3 a .two:focus,
h4 a .two:focus,
h5 a .two:focus,
h1 p .two:focus,
h2 p .two:focus,
h3 p .two:focus,
h4 p .two:focus,
h5 p .two:focus,
h1 div .two:focus,
h2 div .two:focus,
h3 div .two:focus,
h4 div .two:focus,
h5 div .two:focus,
h1 span .two:focus,
h2 span .two:focus,
h3 span .two:focus,
h4 span .two:focus,
h5 span .two:focus,
h1 a .three:focus,
h2 a .three:focus,
h3 a .three:focus,
h4 a .three:focus,
h5 a .three:focus,
h1 p .three:focus,
h2 p .three:focus,
h3 p .three:focus,
h4 p .three:focus,
h5 p .three:focus,
h1 div .three:focus,
h2 div .three:focus,
h3 div .three:focus,
h4 div .three:focus,
h5 div .three:focus,
h1 span .three:focus,
h2 span .three:focus,
h3 span .three:focus,
h4 span .three:focus,
h5 span .three:focus,
h1 a .four:focus,
h2 a .four:focus,
h3 a .four:focus,
h4 a .four:focus,
h5 a .four:focus,
h1 p .four:focus,
h2 p .four:focus,
h3 p .four:focus,
h4 p .four:focus,
h5 p .four:focus,
h1 div .four:focus,
h2 div .four:focus,
h3 div .four:focus,
h4 div .four:focus,
h5 div .four:focus,
h1 span .four:focus,
h2 span .four:focus,
h3 span .four:focus,
h4 span .four:focus,
h5 span .four:focus {
	display: block;
}
.child + .child,
.child + .sibling,
.sibling + .child,
.sibling + .sibling {
	color: red;
}
.child + .child + .child,
.child + .child + .sibling,
.child + .sibling + .child,
.child + .sibling + .sibling,
.sibling + .child + .child,
.sibling + .child + .sibling,
.sibling + .sibling + .child,
.sibling + .sibling + .sibling {
	color: red;
}
.child + .child + .child,
.child + .child + .sibling,
.child + .child + .foo,
.child + .sibling + .child,
.child + .sibling + .sibling,
.child + .sibling + .foo,
.child + .foo + .child,
.child + .foo + .sibling,
.child + .foo + .foo,
.sibling + .child + .child,
.sibling + .child + .sibling,
.sibling + .child + .foo,
.sibling + .sibling + .child,
.sibling + .sibling + .sibling,
.sibling + .sibling + .foo,
.sibling + .foo + .child,
.sibling + .foo + .sibling,
.sibling + .foo + .foo,
.foo + .child + .child,
.foo + .child + .sibling,
.foo + .child + .foo,
.foo + .sibling + .child,
.foo + .sibling + .sibling,
.foo + .sibling + .foo,
.foo + .foo + .child,
.foo + .foo + .sibling,
.foo + .foo + .foo {
	color: red;
}
.child + .child,
.child + .sibling,
.child + .foo,
.sibling + .child,
.sibling + .sibling,
.sibling + .foo,
.foo + .child,
.foo + .sibling,
.foo + .foo {
	color: red;
}
