.row {
	margin-left: -20px;
}
[class*="span"] {
	float: left;
	margin-left: 20px;
}
.span1 {
	width: 60px;
}
.span2 {
	width: 140px;
}
.span3 {
	width: 220px;
}
.span4 {
	width: 300px;
}
.span5 {
	width: 380px;
}
.span6 {
	width: 460px;
}
.span7 {
	width: 540px;
}
.span8 {
	width: 620px;
}
.span9 {
	width: 700px;
}
.span10 {
	width: 780px;
}
.span11 {
	width: 860px;
}
.span12,
.container {
	width: 940px;
}
.offset1 {
	margin-left: 100px;
}
.offset2 {
	margin-left: 180px;
}
.offset3 {
	margin-left: 260px;
}
.offset4 {
	margin-left: 340px;
}
.offset5 {
	margin-left: 420px;
}
.offset6 {
	margin-left: 500px;
}
.offset7 {
	margin-left: 580px;
}
.offset8 {
	margin-left: 660px;
}
.offset9 {
	margin-left: 740px;
}
.offset10 {
	margin-left: 820px;
}
.offset11 {
	margin-left: 900px;
}
.row {
	margin-left: -1.7;
}
[class*="span"] {
	float: left;
	margin-left: 1.7;
}
.span1 {
	width: 27;
}
.span2 {
	width: 55.7;
}
.span3 {
	width: 84.4;
}
.span4 {
	width: 113.1;
}
.span5 {
	width: 141.8;
}
.span6 {
	width: 170.5;
}
.span7 {
	width: 199.2;
}
.span8 {
	width: 227.9;
}
.span9 {
	width: 256.6;
}
.span10 {
	width: 285.3;
}
.span11 {
	width: 314;
}
.span12,
.container {
	width: 342.7;
}
.offset1 {
	margin-left: 30.4;
}
.offset2 {
	margin-left: 59.1;
}
.offset3 {
	margin-left: 87.80000000000001;
}
.offset4 {
	margin-left: 116.5;
}
.offset5 {
	margin-left: 145.20000000000002;
}
.offset6 {
	margin-left: 173.9;
}
.offset7 {
	margin-left: 202.6;
}
.offset8 {
	margin-left: 231.3;
}
.offset9 {
	margin-left: 260;
}
.offset10 {
	margin-left: 288.7;
}
.offset11 {
	margin-left: 317.4;
}
