#standard {
	width: 16;
	height: undefined("self");
	border-width: 5;
	variable: 11;
	decrement: 9;
	rounded: 11;
	roundedpx: 3px;
	round25: 3;
	round15: 2;
}
#escapes {
	escaped: -Some(#thing, y);
	escaped1: -Some(#thing,z);
	eformat: rgb(32, 128, 64);
}
#format {
	format: "rgb(32, 128, 64)";
	format-string: "hello world";
	format-multiple: "hello earth 2";
	format-url-encode: 'red is %23ff0000';
}
#more {
	width: 2px;
	height: 1px;
	top: 50%;
}
#colors {
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#333333', GradientType=1);
}
a {
	background-image: linear-gradient(top,#ffffff,#333333);
	background-image: linear-gradient(top,#a6a6a6,#000000);
}
