.well {
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff555555 ');
	color: rgba(90,23,148,0.5);
	color: #ff646464;
	color: #ff8c6464;
	color: #ff5a1794;
	color: #805a1794;
	color: #ff555555;
}
