@fat: 0;
@cloudhead: "#000000";
//
// IE Filters
//
.nav {
	filter: ~'progid:DXImageTransform.Microsoft.gradient(startColorstr="#333333", endColorstr="@{cloudhead}", GradientType=@{fat})';
}
.nav1 {
	filter: ~"progid:DXImageTransform.Microsoft.Alpha(opacity=@{fat})";
}
.nav2 {
	filter: ~'progid:DXImageTransform.Microsoft.gradient(startColorstr="#333333", endColorstr="@{cloudhead}", GradientType=@{fat})';
}
//
// IE Hacks
//
body {
	*zoom: 1px;
}
>body {
	*zoom: 1px;
}
/* IE6 IFRAME FIX (taken from datepicker 1.5.3 */
.ui-datepicker-cover {
    display: none; /*sorry for IE5*/
    display: block; /*sorry for IE5*/
    position: absolute; /*must have*/
    z-index: -1; /*must have*/
    filter: mask(); /*must have*/
    top: -4px; /*must have*/
    left: -4px; /*must have*/
    width: 200px; /*must have*/
    height: 200px; /*must have*/
}
