#strings {
  	quotes: "~" "~";
  	content: "#*%:&^,)!.(~*})";
  	empty: "";
  	brackets: "{" "}";
}
#comments {
  	content: "/* hello */ // not-so-secret";
}
#quotes {
  	quotes: "'" "'";
  	quotes: '"' '"';
  	content: '""#!&""';
  	empty: '';
  	semi-colon: ';';
}
#escaped {
  	filter: ~"DX.Transform.MS.BS.filter(opacity=50)";
}
.escaped {
  	filter: ~'alpha(opacity=0.1)';
}
#interpolation {
  	@var: '/dev';
  	url: "http://lesscss.org@{var}/image.jpg";

  	@var2: 256;
  	url2: "http://lesscss.org/image-@{var2}.jpg";

  	@var3: #456;
  	url3: "http://lesscss.org@{var3}";

  	@var4: hello;
  	url4: "http://lesscss.org/@{var4}";

  	@var5: 54.4px;
 	url5: "http://lesscss.org/@{var5}";
}
