.scope {
    @var: 99px;
    .mixin () {
        width: @var;
    }
}

.class {
    .scope > .mixin;
}

.overwrite {
    @var: 0px;
    .scope > .mixin;
}

.nested {
    @var: 5px;
    .mixin () {
        width: @var;
    }
    .class {
        @var: 10px;
        .nested .mixin();
    }
}
