"""
    Reserved token names

    Copyright (c)
    See LICENSE for details.
    <jtm@robot.is>
"""

tokens = {
    '@media': 'css_media',
    '@page': 'css_page',
    '@import': 'css_import',
    '@charset': 'css_charset',
    '@font-face': 'css_font_face',
    '@namespace': 'css_namespace',
    '@keyframes': 'css_keyframes',
    '@-moz-keyframes': 'css_keyframes',
    '@-webkit-keyframes': 'css_keyframes',
    '@-ms-keyframes': 'css_keyframes',
    '@-o-keyframes': 'css_keyframes',

    '@viewport': 'css_viewport',
    '@-ms-viewport': 'css_viewport',

    '@arguments': 'less_arguments',
}
