/*
	CSS Properties
*/
div.properties {
	color: red;
}
div.empty {
	margin: ;
}
div.important {
	color: red !important;
  	width: 100%!important;
  	height: 20px ! important;
}
div.annoying_font_property {
	font : 12px/16px Arial;
	font: 100%/16px Arial;
	font: normal small/20px 'Trebuchet MS', Verdana, sans-serif; 
}
div.shorthands {
	border: 1px solid #000;
  	margin: 1px 0;
  	padding: 0 auto;
  	padding: 1px 0 2px 0;
  	margin: 0;
  	padding: -1px -0 -2px -0;
}
/*

*/
table {
  	counter-reset: group;
}
tbody {
  	counter-increment: group;
  	counter-reset: row;
}
tbody tr {
  	counter-increment: row;
}
tbody td:first-child:before {
  	content: counter(group, upper-latin) "." counter(row);
}
/*
	Escapes
*/
.escape\|random\|char {
	color: red;
}
.mixin\!tUp {
	font-weight: bold;
}
.trailingTest\+ {
	color: red;
}
.sr-only {
    clip: rect(0 0 0 0);
}
.font-madness {
	font: 0/0 a;
}
