@-webkit-keyframes progress-bar-stripes {
	from {
		background-position: 0 0;
	}
	to {
		background-position: 40px 0;
	}
}
@-moz-keyframes progress-bar-stripes {
	from {
		background-position: 0 0;
	}
	to {
		background-position: 40px 0;
	}
}
@keyframes progress-bar-stripes {
	from {
		background-position: 0 0;
	}
	to {
		background-position: 40px 0;
	}
}
@keyframes using-percentages {
	0% {
		top: 0;
	}
	50% {
		top: 1px;
	}
	100% {
		top: 2px;
	}
}
@keyframes mixed-in {
	from {
		left: 0;
	}
	50% {
		left: 1px;
	}
	to {
		left: 2px;
	}
}
