.a {
	width: 1px;
	height: -1px;
	padding: 0;
	padding: 0;
	padding: 0;
}
.b {
	margin: 11;
	margin: -11;
}
.c {
	height: 5px;
	width: 5px;
}
.d {
	src: 'mobile';
	padding: 1px;
}
.e {
	width: 9px;
	color: yellow;
	src: 'http://www.lesscss.org/#-parametric-mixins';
	filter: 'wtf';
	ignore: when;
}
.f {
	width: 9px;
	height: -9px;
}
.a .span5 {
	width: 5px;
}
