span {
	padding: 1px;
	padding: 2px;
	padding: 2px;
	padding: 1px;
}
input,
textarea,
.uneditable-input {
	margin-left: 0;
}
input.span12,
textarea.span12,
.uneditable-input.span12 {
	width: 354;
}
input.span11,
textarea.span11,
.uneditable-input.span11 {
	width: 322;
}
input.span10,
textarea.span10,
.uneditable-input.span10 {
	width: 290;
}
input.span9,
textarea.span9,
.uneditable-input.span9 {
	width: 258;
}
input.span8,
textarea.span8,
.uneditable-input.span8 {
	width: 226;
}
input.span7,
textarea.span7,
.uneditable-input.span7 {
	width: 194;
}
input.span6,
textarea.span6,
.uneditable-input.span6 {
	width: 162;
}
input.span5,
textarea.span5,
.uneditable-input.span5 {
	width: 130;
}
input.span4,
textarea.span4,
.uneditable-input.span4 {
	width: 98;
}
input.span3,
textarea.span3,
.uneditable-input.span3 {
	width: 66;
}
input.span2,
textarea.span2,
.uneditable-input.span2 {
	width: 34;
}
input.span1,
textarea.span1,
.uneditable-input.span1 {
	width: 2;
}
